Crate boltz_component

Crate boltz_component 

Component

This module provides the Component trait, which is used to define components for visual testing and debugging.

Additionally, it includes layouts for rendering component examples and example groups, as well as the distributed slice mechanism for registering components.

Structs

ComponentExample
A single example of a component.
ComponentExampleGroup
A group of component examples.
ComponentFn
ComponentId
ComponentMetadata
ComponentRegistry

Enums

ComponentScope
ComponentStatus
The ready status of this component.

Statics

COMPONENT_DATA

Traits

Component
Implement this trait to define a UI component. This will allow you to derive RegisterComponent on it, in turn allowing you to preview the contents of the preview fn in workspace: open component preview.

Functions

components
empty_example
example_group
example_group_with_title
init
register_component
single_example