Component
This module provides the Component trait, which is used to define components for visual testing and debugging.
Additionally, it includes layouts for rendering component examples and example groups, as well as the distributed slice mechanism for registering components.
Structs
- Component
Example - A single example of a component.
- Component
Example Group - A group of component examples.
- Component
Fn - Component
Id - Component
Metadata - Component
Registry
Enums
- Component
Scope - Component
Status - The ready status of this component.
Statics
Traits
- Component
- Implement this trait to define a UI component. This will allow you to
derive
RegisterComponenton it, in turn allowing you to preview the contents of the preview fn inworkspace: open component preview.